logo

logo

Crate etcd_rs

  • Version 1.0.1
  • All Items
  • Structs
  • Enums
  • Traits
  • Type Definitions
?
Change settings

Crate etcd_rs

source ·
An asynchronously etcd client for Rust.

etcd-rs supports etcd v3 API and async/await syntax.

Structs

  • AuthenticateRequest
  • AuthenticateResponse
  • Client
    Client is an abstraction for grouping etcd operations and managing underlying network communications.
  • ClientConfig
    Config for establishing etcd client.
  • CompactRequest
  • CompactResponse
  • DeleteRequest
  • DeleteResponse
  • Endpoint
  • Event
    Every change to every key is represented with Event messages.
  • KeyRange
    KeyRange is an abstraction for describing etcd key of various types.
  • KeyValue
    Key-Value pair.
  • LeaseGrantRequest
  • LeaseGrantResponse
  • LeaseKeepAlive
  • LeaseKeepAliveRequest
  • LeaseKeepAliveResponse
  • LeaseRevokeRequest
  • LeaseRevokeResponse
  • LeaseTimeToLiveRequest
  • LeaseTimeToLiveResponse
  • Member
  • MemberAddRequest
  • MemberAddResponse
  • MemberListRequest
  • MemberListResponse
  • MemberRemoveRequest
  • MemberRemoveResponse
  • MemberUpdateRequest
  • MemberUpdateResponse
  • PutRequest
  • PutResponse
  • RangeRequest
  • RangeResponse
  • ResponseHeader
  • TxnRequest
  • TxnResponse
  • WatchCancelRequest
  • WatchCanceler
  • WatchCreateRequest
  • WatchResponse
  • WatchStream

Enums

  • Error
  • EventType
    The kind of event.
  • TxnCmp
    Transaction Comparation.
  • TxnOp
    Transaction Operation.
  • TxnOpResponse
    Response transaction operation.
  • WatchInbound

Traits

  • AuthOp
  • ClusterOp
  • KeyValueOp
  • LeaseOp
  • WatchOp

Type Definitions

  • LeaseId
  • Result