pub struct Client { /* private fields */ }Expand description
Client is an abstraction for grouping etcd operations and managing underlying network communications.
Implementations
Sourceimpl Client
impl Client
Sourcepub fn with_channel(channel: Channel, token: Option<String>) -> Self
pub fn with_channel(channel: Channel, token: Option<String>) -> Self
Build clients from tonic Channel directly.
For advanced users, it provides the ability to control more details about the connection.
pub async fn connect_with_token( cfg: &ClientConfig, token: Option<String>, ) -> Result<Self>
Sourcepub async fn connect(cfg: ClientConfig) -> Result<Self>
pub async fn connect(cfg: ClientConfig) -> Result<Self>
Connects to etcd cluster and returns a client.
Errors
Will returns Err if failed to contact with given endpoints or authentication failed.